@@ -1,4 +1,4 @@
-/* Copyright 2002-2005 Elliotte Rusty Harold
+/* Copyright 2002-2006, 2009 Elliotte Rusty Harold
    
    This library is free software; you can redistribute it and/or modify
    it under the terms of version 2.1 of the GNU Lesser General Public 
@@ -53,7 +53,7 @@ import org.apache.xerces.impl.Version;
  * </p>
  * 
  * @author Elliotte Rusty Harold
- * @version 1.1b7
+ * @version 1.2
  * 
  */
 public class Builder {
@@ -67,9 +67,16 @@ public class Builder {
     static {  
 
         try {
-            String versionString = Version.getVersion();
-            versionString = versionString.substring(9, 12);
-            xercesVersion = Double.valueOf(versionString).doubleValue();
+            String x = Version.getVersion();
+            String versionString = x.substring(9);
+            int firstPeriod = versionString.indexOf(".");
+            int secondPeriod = versionString.lastIndexOf(".");
+            String major = versionString.substring(0, firstPeriod);
+            String minor = versionString.substring(firstPeriod+1, secondPeriod);
+            if (Integer.parseInt(minor) < 10 && Integer.parseInt(major) < 3) {
+                xercesVersion = Double.parseDouble(x.substring(9,12));
+            }
+            // else it's 2.6 or later which is all we really need to know
         }
         catch (Exception ex) {
             // The version string format changed so presumably it's
@@ -166,6 +173,8 @@ public class Builder {
         "nu.xom.XML1_0Parser",
         "nu.xom.JDK15XML1_0Parser",
         "org.apache.xerces.parsers.SAXParser",
+        "org.apache.xerces.jaxp.SAXParserImpl$JAXPSAXParser", // xerces-2.9.x
+        "com.sun.org.apache.xerces.internal.jaxp.SAXParserImpl$JAXPSAXParser", // JDK 1.6
         "com.sun.org.apache.xerces.internal.parsers.SAXParser",
         "gnu.xml.aelfred2.XmlReader",
         "org.apache.crimson.parser.XMLReaderImpl",
@@ -260,9 +269,11 @@ public class Builder {
         }
         
         String parserName = baseParser.getClass().getName();
+        parser.setFeature(
+          "http://xml.org/sax/features/namespace-prefixes", true);
+        parser.setFeature(
+          "http://xml.org/sax/features/namespaces", true);
         if (!validate) {
-            parser.setFeature(
-              "http://xml.org/sax/features/namespace-prefixes", true);
             if (parserName.equals(  // Crimson workaround
               "org.apache.crimson.parser.XMLReaderImpl")) {
                 parser.setErrorHandler(
@@ -280,9 +291,7 @@ public class Builder {
                 );
             }
         }
-        else {  
-            parser.setFeature(
-              "http://xml.org/sax/features/namespace-prefixes", true);
+        else {
             parser.setFeature(
               "http://xml.org/sax/features/validation", true);
             parser.setErrorHandler(new ValidityRequired());
@@ -301,7 +310,10 @@ public class Builder {
         if (parserName.equals("nu.xom.XML1_0Parser") 
          || parserName.equals("nu.xom.JDK15XML1_0Parser")
          || parserName.equals("org.apache.xerces.parsers.SAXParser")
-         || parserName.equals("com.sun.org.apache.xerces.internal.parsers.SAXParser")) {
+         || parserName.equals("com.sun.org.apache.xerces.internal.parsers.SAXParser")
+         || parserName.equals("org.apache.xerces.jaxp.SAXParserImpl$JAXPSAXParser") // xerces-2.9.x
+         || parserName.equals("com.sun.org.apache.xerces.internal.jaxp.SAXParserImpl$JAXPSAXParser")) // JDK 1.6
+        {
             try {
                 parser.setFeature(
                  "http://apache.org/xml/features/allow-java-encodings", true);
@@ -576,12 +588,14 @@ public class Builder {
      * @throws ValidityException if a validity error is detected; 
      *     only thrown if the builder has been instructed to validate
      * @throws ParsingException  if a well-formedness error is detected
-     * @throws IOException  if an I/O error such as a broken 
-     *     socket prevents the document from being fully read.
+     * @throws IOException       if an I/O error such as a broken 
+     *     socket prevents the document from being fully read
+     * @throws NullPointerException  if <code>in</code> is null
      */
     public Document build(InputStream in) 
       throws ParsingException, ValidityException, IOException {
 
+        if (in == null) throw new NullPointerException("Null InputStream");
         InputSource source = new InputSource(in);
         return build(source);
         
@@ -960,7 +974,7 @@ public class Builder {
                             i++;
                             try {
                                 char low = absolute.charAt(i);
-                                String character = String.valueOf(c)+String.valueOf(low);
+                                String character = String.valueOf(c)+low;
                                 byte[] data = character.getBytes("UTF8");
                                 // Always exactly 4 bytes, unless the encoder is buggy
                                 for (int j=0; j < 4; j++) {
@@ -1079,21 +1093,41 @@ public class Builder {
     
     // needed to work around a bug in Xerces and Crimson
     // for URLs with no trailing slashes (no path part) 
-    // such as http://www.cafeconleche.org
+    // such as http://www.cafeconleche.org.
+    // Also needed to work around a VM bug involving file URLs such as
+    // file:///tmp/nosuchdirectory/../foo.xml
+    // where "nosuchdirectory" does not exist.
+    // ???? should this move into the URIUtil class?
     private String canonicalizeURL(String uri) {
         
         try {
             URL u = new URL(uri);
             String path = u.getFile();
+            String scheme = u.getProtocol();
+            String authority = u.getHost();
+            String query = u.getQuery();
+            int port = u.getPort();
+            // fragment ID not needed
             if (path == null || path.length() == 0 
               // We handle here the case where we have a URL such as 
               // http://www.cafeaulait.org with no trailing slash.
               // Java's URL class assigns the path "/" to this case
               // but does not change the URL. 
               || ("/".equals(path) && !(uri.endsWith("/")))) {
-                uri += '/';
+                path += '/';
             }
-            return uri;
+            // If this proves to be a hot spot we could probably take this path
+            // only if the scheme is file; not in the more common case where
+            // it's http
+            path = URIUtil.removeDotSegments(path);
+            StringBuffer canonicalForm = new StringBuffer(uri.length()); 
+            canonicalForm.append(scheme);
+            canonicalForm.append("://");
+            if (authority != null) canonicalForm.append(authority); 
+            if (port >= 0) canonicalForm.append(":" + port);
+            canonicalForm.append(path);
+            if (query != null) canonicalForm.append("?" + query);
+            return canonicalForm.toString();
         }
         catch (MalformedURLException ex) {
             return uri;
@@ -1126,7 +1160,6 @@ public class Builder {
         try {
             parser.parse(in);
             result = handler.getDocument();
-
         }
         catch (SAXParseException ex) {
             ParsingException pex = new ParsingException(
@@ -1276,7 +1309,7 @@ public class Builder {
     // I added this because XIncluder needed it.
     /**
      * <p>
-     * Returns this builder's <code>NodeFactory</code>. It may return
+     * Returns this builder's <code>NodeFactory</code>. It returns
      * null if a factory was not supplied when the builder was created.
      * </p>
      * 
