@@ -1,4 +1,4 @@
-/* Copyright 2004, 2005 Elliotte Rusty Harold
+/* Copyright 2004-2006 Elliotte Rusty Harold
    
    This library is free software; you can redistribute it and/or modify
    it under the terms of version 2.1 of the GNU Lesser General Public 
@@ -32,7 +32,7 @@ import java.io.UnsupportedEncodingException;
  * but may well not be true in a more general context. 
  * 
  * @author Elliotte Rusty Harold
- * @version 1.1b4
+ * @version 1.2d1
  *
  */
 class URIUtil {
@@ -150,9 +150,9 @@ class URIUtil {
     }
     
     
-    private static String removeDotSegments(String path) {
+    static String removeDotSegments(String path) {
     
-        String output = "";
+        StringBuffer output = new StringBuffer();
 
         while (path.length() > 0) {
             if (path.startsWith("/./")) {
@@ -163,18 +163,18 @@ class URIUtil {
             }
             else if (path.startsWith("/../")) {
                 path = '/' + path.substring(4);
-                int lastSlash = output.lastIndexOf('/');
-                if (lastSlash != -1) output = output.substring(0, lastSlash);
+                int lastSlash = output.toString().lastIndexOf('/');
+                if (lastSlash != -1) output.setLength(lastSlash);
             }
             else if (path.equals("/..")) {
                 path = "/";
-                int lastSlash = output.lastIndexOf('/');
-                if (lastSlash != -1) {
-                    output = output.substring(0, lastSlash);
-                }
+                int lastSlash = output.toString().lastIndexOf('/');
+                if (lastSlash != -1) output.setLength(lastSlash);
             }
             // These next three cases are unreachable in the context of XOM.
             // They may be needed in a more general public URIUtil.
+            // ???? need to consider whether these are still unreachable now that
+            // Builder.canonicalizeURL is calling this method.
             /* else if (path.equals(".") || path.equals("..")) {
                 path = "";
             }
@@ -188,17 +188,17 @@ class URIUtil {
                 int nextSlash = path.indexOf('/');
                 if (nextSlash == 0) nextSlash = path.indexOf('/', 1);
                 if (nextSlash == -1) {
-                    output += path;
+                    output.append(path);
                     path = "";
                 }
                 else {
-                    output += path.substring(0, nextSlash);
+                    output.append(path.substring(0, nextSlash));
                     path = path.substring(nextSlash);
                 }
             }
         }
         
-        return output;
+        return output.toString();
         
     }
 
@@ -650,34 +650,31 @@ class URIUtil {
 
 
     static String relativize(String base, String abs) {
- 
-        try {
-            ParsedURI parsedBase = new ParsedURI(base);
-            ParsedURI parsedAbs  = new ParsedURI(abs);
+
+        ParsedURI parsedBase = new ParsedURI(base);
+        ParsedURI parsedAbs  = new ParsedURI(abs);
+        
+        parsedBase.path = removeDotSegments(parsedBase.path);
+        
+        if (parsedBase.scheme.equals(parsedAbs.scheme)
+          && parsedBase.authority.equals(parsedAbs.authority)) {
+        
+            String basePath = parsedBase.path;
+            String relPath = parsedAbs.path;
             
-            if (parsedBase.scheme.equals(parsedAbs.scheme)
-              && parsedBase.authority.equals(parsedAbs.authority)) {
-                
-            
-                String basePath = parsedBase.path;
-                String relPath = parsedAbs.path;
-                
-                while (basePath.length() > 1) {
-                    basePath = basePath.substring(0, basePath.lastIndexOf('/'));
-                    if (relPath.startsWith(basePath)) {
-                        return relPath.substring(basePath.length()+1);
-                    }
+            while (basePath.length() > 1) {
+                basePath = basePath.substring(0, basePath.lastIndexOf('/'));
+                if (relPath.startsWith(basePath)) {
+                    return relPath.substring(basePath.length()+1);
                 }
-                
-                return relPath;
-            }
-            else {
-                return abs;
             }
+            
+            return relPath;
         }
-        catch (Exception ex) {
+        else {
             return abs;
         }
+
     }
 
     
