@@ -1,4 +1,4 @@
-/* Copyright 2002-2005 Elliotte Rusty Harold
+/* Copyright 2002-2006 Elliotte Rusty Harold
    
    This library is free software; you can redistribute it and/or modify
    it under the terms of version 2.1 of the GNU Lesser General Public 
@@ -32,7 +32,7 @@ import org.xml.sax.ext.LexicalHandler;
 
 /**
  * @author Elliotte Rusty Harold
- * @version 1.1b7
+ * @version 1.2b1
  *
  */
 class XOMHandler 
@@ -75,8 +75,8 @@ class XOMHandler
 
 
     // See http://www.servlets.com/archive/servlet/ReadMsg?msgId=554071&listName=jdom-interest
-    // This method is called to avoid leaking document sized leaking memory
-    // when a Builder is not imediately reused
+    // This method is called to avoid leaking document sized memory
+    // when a Builder is not immediately reused
     void freeMemory() {
         document = null;
         parent = null;
@@ -336,7 +336,7 @@ class XOMHandler
  
     
     // accumulate all text that's in the buffer into a text node
-    protected void flushText() {
+    private void flushText() {
         
         if (buffer != null) {
             textString = buffer.toString();
@@ -582,8 +582,10 @@ class XOMHandler
             if (defaultValue != null) {
                 internalDTDSubset.append(' ');
                 internalDTDSubset.append('"');
-                internalDTDSubset.append(escapeReservedCharactersInDefaultAttributeValues(defaultValue));
-                internalDTDSubset.append("\"");         
+                internalDTDSubset.append(
+                  escapeReservedCharactersInDefaultAttributeValues(defaultValue)
+                );
+                internalDTDSubset.append('\"');         
             }
             internalDTDSubset.append(">\n");   
         }
@@ -613,7 +615,7 @@ class XOMHandler
     
     public void externalEntityDecl(String name, 
        String publicID, String systemID) {
-        
+
         if (inInternalSubset() && doctype != null) {
             internalDTDSubset.append("  <!ENTITY ");
             if (name.startsWith("%")) { 
@@ -645,7 +647,7 @@ class XOMHandler
                 internalDTDSubset.append(systemID);       
             }
             else {
-                // need to escape system ID????
+                // need to escape system ID???? could it contain an ampersand?
                 internalDTDSubset.append(" SYSTEM \""); 
                 internalDTDSubset.append(systemID); 
             }
