@@ -46,7 +46,7 @@ import nu.xom.WellformednessException;
  * </p>
  * 
  * @author Elliotte Rusty Harold
- * @version 1.1b4
+ * @version 1.2b3
  *
  */
 public class DocTypeTest extends XOMTestCase {
@@ -57,9 +57,9 @@ public class DocTypeTest extends XOMTestCase {
     }
     
     
-    String name = "MyName";
-    String systemID = "http://www.w3.org/TR/some.dtd";
-    String publicID = "-//Me//some public ID";
+    private String name = "MyName";
+    private String systemID = "http://www.w3.org/TR/some.dtd";
+    private String publicID = "-//Me//some public ID";
 
 
     // This class tests error conditions, which Xerces
@@ -344,20 +344,19 @@ public class DocTypeTest extends XOMTestCase {
     
     public void testSetInternalDTDSubsetWithRelativeURLAndCrimson() 
       throws ParsingException, IOException {
-        
-        XMLReader crimson;
+            
         try {
-            crimson = XMLReaderFactory.createXMLReader(
+            XMLReader crimson = XMLReaderFactory.createXMLReader(
               "org.apache.crimson.parser.XMLReaderImpl");
+            Builder builder = new Builder(crimson);
+            Document doc = builder.build("data/outer21.xml");
+            String subset = doc.getDocType().getInternalDTDSubset();
+            assertEquals(subset, subset.indexOf("file:/"), -1);
         } 
         catch (SAXException ex) {
             // can't test Crimson if you can't load it
             return;
         }
-        Builder builder = new Builder(crimson);
-        Document doc = builder.build("data/outer21.xml");
-        String subset = doc.getDocType().getInternalDTDSubset();
-        assertEquals(subset, subset.indexOf("file:/"), -1);
 
     }
     
