@@ -50,7 +50,7 @@ import nu.xom.Text;
  * </p>
  * 
  * @author Elliotte Rusty Harold
- * @version 1.1b2
+ * @version 1.2
  *
  */
 public class ElementTest extends XOMTestCase {
@@ -119,6 +119,26 @@ public class ElementTest extends XOMTestCase {
         
     }
     
+    private static class TestElement extends Element {
+
+        public TestElement(String name) {
+            super(name);
+        }
+        
+        public String toString() {
+            return "foo";
+        }
+        
+    }
+    
+    
+    public void testOverrideToString() {
+        
+        Element element = new TestElement("bar");
+        assertEquals("foo", element.toString());
+        
+    }
+    
     
     public void testGetFirstChildElement() {
         
@@ -272,6 +292,12 @@ public class ElementTest extends XOMTestCase {
     }
     
     
+    public void testPhilip() {
+        Element element = new Element("x", "x:&");
+        assertEquals("<x xmlns=\"x:&amp;\" />", element.toXML());
+    }
+    
+    
     public void testToXMLWithXMLLangAttribute() {
         Element e = new Element("e");
         e.addAttribute(new Attribute("xml:lang",
