@@ -1,4 +1,4 @@
-/* Copyright 2005 Elliotte Rusty Harold
+/* Copyright 2005, 2006 Elliotte Rusty Harold
    
    This library is free software; you can redistribute it and/or modify
    it under the terms of version 2.1 of the GNU Lesser General Public 
@@ -34,6 +34,7 @@ import nu.xom.DocType;
 import nu.xom.Document;
 import nu.xom.Element;
 import nu.xom.Elements;
+import nu.xom.IllegalNameException;
 import nu.xom.Namespace;
 import nu.xom.NamespaceConflictException;
 import nu.xom.Node;
@@ -51,7 +52,7 @@ import nu.xom.XPathTypeException;
  * </p>
  * 
  * @author Elliotte Rusty Harold
- * @version 1.1b4
+ * @version 1.2b3
  *
  */
 public class XPathTest extends XOMTestCase {
@@ -304,7 +305,7 @@ public class XPathTest extends XOMTestCase {
         
     }
     
-    
+    /* Commented out because files have been removed 
     public void testFranceschet1() throws ParsingException, IOException {
      
         Builder builder = new Builder();
@@ -416,7 +417,7 @@ public class XPathTest extends XOMTestCase {
             }
         }
         
-    }
+    } */
     
 
     public void testQueryThatReturnsNumber() {
@@ -653,6 +654,44 @@ public class XPathTest extends XOMTestCase {
     }
     
 
+    public void testCantBindNonPrefix() {
+        
+        XPathContext context = new XPathContext();
+        try {
+            context.addNamespace("foo:bar", "http://www.example.org");
+            fail("Allowed preix with colon");
+        }
+        catch (IllegalNameException success) {
+            assertNotNull(success.getMessage());
+        }
+        
+        try {
+            context.addNamespace("foo bar", "http://www.example.org");
+            fail("Allowed preix with space");
+        }
+        catch (IllegalNameException success) {
+            assertNotNull(success.getMessage());
+        }
+        
+    }
+    
+
+    public void testLookupPrefix() {
+        XPathContext context = new XPathContext();
+        context.addNamespace("foo", "http://www.example.org");
+        String url = context.lookup("foo");
+        assertEquals("http://www.example.org", url);
+    }
+    
+
+    public void testLookupNonexistentPrefix() {
+        XPathContext context = new XPathContext();
+        context.addNamespace("foo", "http://www.example.org");
+        String url = context.lookup("bar");
+        assertNull(url);
+    }
+    
+
     public void testParentAxis() {
         
         Element parent = new Element("Test");
@@ -2212,15 +2251,17 @@ public class XPathTest extends XOMTestCase {
     
     public void testJaxenIntegrationTest() throws ParsingException, IOException {
         
+        // TODO point this, at least optionally, at the jaxen directory in the zip file instead.
+        // However, first you'll have to push a jaxen 1.2.1 that fixes tests.xml.
+        String base = "http://svn.jaxen.codehaus.org/browse/~raw,r=trunk/jaxen/trunk/jaxen/";
         Builder builder = new Builder();
-        Document testDoc = builder.build(
-          "http://cvs.jaxen.codehaus.org/viewrep/~raw,r=HEAD/jaxen/jaxen/xml/test/tests.xml");
+        Document testDoc = builder.build(base + "xml/test/tests.xml");
         Elements documents = testDoc.getRootElement().getChildElements("document");
         for (int i = 0; i < documents.size(); i++) {
             Element documentElement = documents.get(i);
             String url = documentElement.getAttributeValue("url");
             Document source = builder.build(
-              "http://cvs.jaxen.codehaus.org/viewrep/~raw,r=HEAD/jaxen/jaxen/" 
+              "http://svn.jaxen.codehaus.org/browse/~raw,r=trunk/jaxen/trunk/jaxen/" 
               + url);
             Elements contextElements = documentElement.getChildElements("context");
             for (int j = 0; j < contextElements.size(); j++) {
